==> haskell-conversion-text-1.0.1.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conversion-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 conversion-text
version:              1.0.1.1
visibility:           public
id:                   conversion-text-1.0.1.1-HL7sDRSksbfJGmRcMeDKzi
key:                  conversion-text-1.0.1.1-HL7sDRSksbfJGmRcMeDKzi
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/conversion-text 
synopsis:             "Conversion" instances for the "text" library 
category:             Control, Data, Conversion
abi:                  fa454726ce7537c0abe4c74856d3cf6b
exposed:              True
exposed-modules:      Conversion.Text
import-dirs:          /usr/lib/ghc-9.0.2/site-local/conversion-text-1.0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/conversion-text-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conversion-text
hs-libraries:         HSconversion-text-1.0.1.1-HL7sDRSksbfJGmRcMeDKzi
depends:
    base-prelude-1.6.1-7G8REA7jrPZCXST4e4gmWo bytestring-0.10.12.1
    conversion-1.2.1-7uKM7cNhrc0LASHevjXbk1
    conversion-bytestring-1.0.1.1-4UEQQucB0A3KdMbSiSSm text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-conversion-text/html/conversion-text.haddock

haddock-html:         /usr/share/doc/haskell-conversion-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conversion-text-1.0.1.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conversion-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 conversion-text
version:              1.0.1.1
visibility:           public
id:                   conversion-text-1.0.1.1-61J7YN7X8ww2eJINrqhNCk
key:                  conversion-text-1.0.1.1-61J7YN7X8ww2eJINrqhNCk
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/conversion-text 
synopsis:             "Conversion" instances for the "text" library 
category:             Control, Data, Conversion
abi:                  09c63b156bed020e81bf8451fd105949
exposed:              True
exposed-modules:      Conversion.Text
import-dirs:          /usr/lib/ghc-9.0.2/site-local/conversion-text-1.0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/conversion-text-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conversion-text
hs-libraries:         HSconversion-text-1.0.1.1-61J7YN7X8ww2eJINrqhNCk
depends:
    base-prelude-1.6.1.1-wQJoDOwMJQ1UxEfUaFn2i bytestring-0.10.12.1
    conversion-1.2.1-18vuvxc6sssKITroGAXHvc
    conversion-bytestring-1.0.1.1-Cj2wz3rhYzmEzdHY1CZokr text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-conversion-text/html/conversion-text.haddock

haddock-html:         /usr/share/doc/haskell-conversion-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
